"use client";

import { Card } from "@/components/ui/card";
import { Badge } from "@/components/ui/badge";
import { Button } from "@/components/ui/button";
import { School } from "@/types/school";
import { MapPin, Users, Star, GraduationCap, ExternalLink } from "lucide-react";
import Image from "next/image";

interface SchoolCardProps {
  school: School;
}

export default function SchoolCard({ school }: SchoolCardProps) {
  return (
    <Card className="p-6 hover:shadow-lg transition-shadow duration-300">
      <div className="flex gap-6">
        <div className="relative h-32 w-32 flex-shrink-0">
          <Image
            src={school.logo}
            alt={school.name}
            fill
            className="object-contain"
          />
        </div>

        <div className="flex-1 min-w-0">
          <div className="flex items-start justify-between gap-4">
            <div>
              <h3 className="text-xl font-semibold">{school.name}</h3>
              <div className="flex items-center gap-2 text-muted-foreground mt-1">
                <MapPin className="h-4 w-4" />
                <span>{school.location}</span>
              </div>
            </div>
            <div className="flex items-center gap-1">
              <Star className="h-5 w-5 fill-yellow-400 text-yellow-400" />
              <span className="font-semibold">{school.rating.toFixed(1)}</span>
            </div>
          </div>

          <div className="mt-4 grid grid-cols-2 gap-4">
            <div className="flex items-center gap-2 text-sm text-muted-foreground">
              <Users className="h-4 w-4" />
              <span>{school.studentCount.toLocaleString()} students</span>
            </div>
            <div className="flex items-center gap-2 text-sm text-muted-foreground">
              <GraduationCap className="h-4 w-4" />
              <span>Acceptance rate: {school.acceptanceRate}</span>
            </div>
          </div>

          <div className="mt-4">
            <h4 className="font-medium mb-2">Popular Programs:</h4>
            <div className="flex flex-wrap gap-2">
              {school.programs.map((program) => (
                <Badge key={program} variant="secondary">
                  {program}
                </Badge>
              ))}
            </div>
          </div>

          <div className="mt-4 flex flex-wrap items-center gap-4">
            <Button className="gap-2">
              Apply Now
            </Button>
            <Button variant="outline" className="gap-2">
              <ExternalLink className="h-4 w-4" />
              Visit Website
            </Button>
          </div>
        </div>
      </div>
    </Card>
  );
}